@@ -18,6 +18,13 @@ if TYPE_CHECKING:
     from ..utils.xdg_basedir import XDGPathEntry
     from .news import NewsReadStatusStore
 
+import babel
+# not sure why Pyright insists on individual imports
+# otherwise, at the use site (`except babel.core.UnknownLocaleError`):
+#   error: "core" is not a known attribute of module "babel" (reportAttributeAccessIssue)
+from babel.core import UnknownLocaleError
+
+from ..i18n import _
 from . import errors
 from . import schema
 
@@ -115,7 +122,11 @@ class GlobalConfig:
             if iem is not None and not is_global_scope:
                 iem_cfg_key = f"{schema.SECTION_INSTALLATION}.{schema.KEY_INSTALLATION_EXTERNALLY_MANAGED}"
                 self.logger.W(
-                    f"the config key [yellow]{iem_cfg_key}[/] cannot be set from user config; ignoring",
+                    _(
+                        "the config key [yellow]{key}[/] cannot be set from user config; ignoring"
+                    ).format(
+                        key=iem_cfg_key,
+                    ),
                 )
             else:
                 self.is_installation_externally_managed = bool(iem)
@@ -133,7 +144,11 @@ class GlobalConfig:
             if self.override_repo_dir:
                 if not pathlib.Path(self.override_repo_dir).is_absolute():
                     self.logger.W(
-                        f"the local repo path '{self.override_repo_dir}' is not absolute; ignoring"
+                        _(
+                            "the local repo path '{path}' is not absolute; ignoring"
+                        ).format(
+                            path=self.override_repo_dir,
+                        )
                     )
                     self.override_repo_dir = None
 
@@ -274,6 +289,15 @@ class GlobalConfig:
     def lang_code(self) -> str:
         return self._lang_code
 
+    @cached_property
+    def babel_locale(self) -> babel.Locale:
+        try:
+            return babel.Locale.parse(self.lang_code)
+        except UnknownLocaleError:
+            # this can happen in case of unrecognized locale names, which
+            # apparently falls back to "C"
+            return babel.Locale.parse("en_US")
+
     @property
     def cache_root(self) -> os.PathLike[Any]:
         return self._dirs.app_cache
