@@ -1,6 +1,8 @@
 from os import PathLike
 from typing import Any, Sequence
 
+from ..i18n import _
+
 
 class InvalidConfigSectionError(Exception):
     def __init__(self, section: str) -> None:
@@ -8,7 +10,7 @@ class InvalidConfigSectionError(Exception):
         self._section = section
 
     def __str__(self) -> str:
-        return f"invalid config section: {self._section}"
+        return _("invalid config section: {section}").format(section=self._section)
 
     def __repr__(self) -> str:
         return f"InvalidConfigSectionError({self._section!r})"
@@ -20,7 +22,7 @@ class InvalidConfigKeyError(Exception):
         self._key = key
 
     def __str__(self) -> str:
-        return f"invalid config key: {self._key}"
+        return _("invalid config key: {key}").format(key=self._key)
 
     def __repr__(self) -> str:
         return f"InvalidConfigKeyError({self._key:!r})"
@@ -39,7 +41,13 @@ class InvalidConfigValueTypeError(TypeError):
         self._expected = expected
 
     def __str__(self) -> str:
-        return f"invalid value type for config key {self._key}: {type(self._val)}, expected {self._expected}"
+        return _(
+            "invalid value type for config key {key}: {actual_type}, expected {expected_type}"
+        ).format(
+            key=self._key,
+            actual_type=type(self._val),
+            expected_type=self._expected,
+        )
 
     def __repr__(self) -> str:
         return f"InvalidConfigValueTypeError({self._key!r}, {self._val!r}, {self._expected:!r})"
@@ -58,8 +66,10 @@ class InvalidConfigValueError(ValueError):
         self._typ = typ
 
     def __str__(self) -> str:
-        return (
-            f"invalid config value for key {self._key} (type {self._typ}): {self._val}"
+        return _("invalid config value for key {key} (type {typ}): {val}").format(
+            key=self._key,
+            typ=self._typ,
+            val=self._val,
         )
 
     def __repr__(self) -> str:
@@ -74,7 +84,7 @@ class MalformedConfigFileError(Exception):
         self._path = path
 
     def __str__(self) -> str:
-        return f"malformed config file: {self._path}"
+        return _("malformed config file: {path}").format(path=self._path)
 
     def __repr__(self) -> str:
         return f"MalformedConfigFileError({self._path:!r})"
@@ -86,7 +96,9 @@ class ProtectedGlobalConfigError(Exception):
         self._key = key
 
     def __str__(self) -> str:
-        return f"attempt to modify protected global config key: {self._key}"
+        return _("attempt to modify protected global config key: {key}").format(
+            key=self._key,
+        )
 
     def __repr__(self) -> str:
         return f"ProtectedGlobalConfigError({self._key!r})"
