@@ -2,6 +2,7 @@ import argparse
 from typing import TYPE_CHECKING
 
 from ..cli.cmd import RootCommand
+from ..i18n import _
 
 if TYPE_CHECKING:
     from ..cli.completion import ArgumentParser
@@ -11,7 +12,7 @@ if TYPE_CHECKING:
 class UpdateCommand(
     RootCommand,
     cmd="update",
-    help="Update RuyiSDK repo and packages",
+    help=_("Update RuyiSDK repo and packages"),
 ):
     @classmethod
     def configure_args(cls, gc: "GlobalConfig", p: "ArgumentParser") -> None:
@@ -32,16 +33,20 @@ class UpdateCommand(
 
         if upgradable:
             logger.stdout(
-                "\nNewer versions are available for some of your installed packages:\n"
+                _(
+                    "\nNewer versions are available for some of your installed packages:\n"
+                )
             )
             for pm, new_ver in upgradable:
                 logger.stdout(
                     f"  - [bold]{pm.category}/{pm.name}[/]: [yellow]{pm.ver}[/] -> [green]{new_ver}[/]"
                 )
             logger.stdout(
-                """
+                _(
+                    """
 Re-run [yellow]ruyi install[/] to upgrade, and don't forget to re-create any affected
 virtual environments."""
+                )
             )
 
         news.maybe_notify_unread_news(cfg, False)
